==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/signalrservice/kotlin/inputs/PrivateEndpointACLArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.signalrservice.kotlin.inputs

import com.pulumi.azurenative.signalrservice.inputs.PrivateEndpointACLArgs.builder
import com.pulumi.azurenative.signalrservice.kotlin.enums.SignalRRequestType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * ACL for a private endpoint
 * @property allow Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
 * @property deny Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
 * @property name Name of the private endpoint connection
 */
public data class PrivateEndpointACLArgs(
    public val allow: Output<List<Either<String, SignalRRequestType>>>? = null,
    public val deny: Output<List<Either<String, SignalRRequestType>>>? = null,
    public val name: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.signalrservice.inputs.PrivateEndpointACLArgs> {
    override fun toJava(): com.pulumi.azurenative.signalrservice.inputs.PrivateEndpointACLArgs =
        com.pulumi.azurenative.signalrservice.inputs.PrivateEndpointACLArgs.builder()
            .allow(
                allow?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 ->
                            args0.let({ args0 -> args0.toJava() })
                        })
                    })
                }),
            )
            .deny(
                deny?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 ->
                            args0.let({ args0 -> args0.toJava() })
                        })
                    })
                }),
            )
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PrivateEndpointACLArgs].
 */
@PulumiTagMarker
public class PrivateEndpointACLArgsBuilder internal constructor() {
    private var allow: Output<List<Either<String, SignalRRequestType>>>? = null

    private var deny: Output<List<Either<String, SignalRRequestType>>>? = null

    private var name: Output<String>? = null

    /**
     * @param value Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("itwhcivcltibcujb")
    public suspend fun allow(`value`: Output<List<Either<String, SignalRRequestType>>>) {
        this.allow = value
    }

    @JvmName("nncatysfeiykbglh")
    public suspend fun allow(vararg values: Output<Either<String, SignalRRequestType>>) {
        this.allow = Output.all(values.asList())
    }

    /**
     * @param values Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("ryhiqvgaalwkxrhr")
    public suspend fun allow(values: List<Output<Either<String, SignalRRequestType>>>) {
        this.allow = Output.all(values)
    }

    /**
     * @param value Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("bxsdubuqqtmvskrq")
    public suspend fun deny(`value`: Output<List<Either<String, SignalRRequestType>>>) {
        this.deny = value
    }

    @JvmName("kjcoqjqymptpapqf")
    public suspend fun deny(vararg values: Output<Either<String, SignalRRequestType>>) {
        this.deny = Output.all(values.asList())
    }

    /**
     * @param values Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("laabdopjxlinohpy")
    public suspend fun deny(values: List<Output<Either<String, SignalRRequestType>>>) {
        this.deny = Output.all(values)
    }

    /**
     * @param value Name of the private endpoint connection
     */
    @JvmName("qkbtehjvhrcngfuy")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("sbarigsbseepyyud")
    public suspend fun allow(`value`: List<Either<String, SignalRRequestType>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allow = mapped
    }

    /**
     * @param values Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("rpekgqslyppcfcsq")
    public suspend fun allow(vararg values: Either<String, SignalRRequestType>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allow = mapped
    }

    /**
     * @param value Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("xkcfbitalcuavxqm")
    public suspend fun deny(`value`: List<Either<String, SignalRRequestType>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deny = mapped
    }

    /**
     * @param values Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("pitihfguwmrmokhi")
    public suspend fun deny(vararg values: Either<String, SignalRRequestType>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deny = mapped
    }

    /**
     * @param value Name of the private endpoint connection
     */
    @JvmName("bskuvwgqwhdfaqys")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): PrivateEndpointACLArgs = PrivateEndpointACLArgs(
        allow = allow,
        deny = deny,
        name = name ?: throw PulumiNullFieldException("name"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/signalrservice/kotlin/inputs/PrivateEndpointACLArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.signalrservice.kotlin.inputs

import com.pulumi.azurenative.signalrservice.inputs.PrivateEndpointACLArgs.builder
import com.pulumi.azurenative.signalrservice.kotlin.enums.SignalRRequestType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * ACL for a private endpoint
 * @property allow Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
 * @property deny Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
 * @property name Name of the private endpoint connection
 */
public data class PrivateEndpointACLArgs(
    public val allow: Output<List<Either<String, SignalRRequestType>>>? = null,
    public val deny: Output<List<Either<String, SignalRRequestType>>>? = null,
    public val name: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.signalrservice.inputs.PrivateEndpointACLArgs> {
    override fun toJava(): com.pulumi.azurenative.signalrservice.inputs.PrivateEndpointACLArgs =
        com.pulumi.azurenative.signalrservice.inputs.PrivateEndpointACLArgs.builder()
            .allow(
                allow?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 ->
                            args0.let({ args0 -> args0.toJava() })
                        })
                    })
                }),
            )
            .deny(
                deny?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 ->
                            args0.let({ args0 -> args0.toJava() })
                        })
                    })
                }),
            )
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PrivateEndpointACLArgs].
 */
@PulumiTagMarker
public class PrivateEndpointACLArgsBuilder internal constructor() {
    private var allow: Output<List<Either<String, SignalRRequestType>>>? = null

    private var deny: Output<List<Either<String, SignalRRequestType>>>? = null

    private var name: Output<String>? = null

    /**
     * @param value Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("axxladdtgxhmbesg")
    public suspend fun allow(`value`: Output<List<Either<String, SignalRRequestType>>>) {
        this.allow = value
    }

    @JvmName("kntsrjivjwnkpshh")
    public suspend fun allow(vararg values: Output<Either<String, SignalRRequestType>>) {
        this.allow = Output.all(values.asList())
    }

    /**
     * @param values Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("unlqdsufaonfwinc")
    public suspend fun allow(values: List<Output<Either<String, SignalRRequestType>>>) {
        this.allow = Output.all(values)
    }

    /**
     * @param value Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("elbvtcyolpibnxcb")
    public suspend fun deny(`value`: Output<List<Either<String, SignalRRequestType>>>) {
        this.deny = value
    }

    @JvmName("scdnbfvranxfhhow")
    public suspend fun deny(vararg values: Output<Either<String, SignalRRequestType>>) {
        this.deny = Output.all(values.asList())
    }

    /**
     * @param values Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("mfrcaxevhnvfpbpj")
    public suspend fun deny(values: List<Output<Either<String, SignalRRequestType>>>) {
        this.deny = Output.all(values)
    }

    /**
     * @param value Name of the private endpoint connection
     */
    @JvmName("nkdvdpnawuflybri")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("pogxtaskhdjmcisv")
    public suspend fun allow(`value`: List<Either<String, SignalRRequestType>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allow = mapped
    }

    /**
     * @param values Allowed request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("dnbvavusxjriitse")
    public suspend fun allow(vararg values: Either<String, SignalRRequestType>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allow = mapped
    }

    /**
     * @param value Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("gmppobuiwtidyosh")
    public suspend fun deny(`value`: List<Either<String, SignalRRequestType>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deny = mapped
    }

    /**
     * @param values Denied request types. The value can be one or more of: ClientConnection, ServerConnection, RESTAPI.
     */
    @JvmName("qkaqnapuxamknlyh")
    public suspend fun deny(vararg values: Either<String, SignalRRequestType>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deny = mapped
    }

    /**
     * @param value Name of the private endpoint connection
     */
    @JvmName("bnxosmnavgyqbflr")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): PrivateEndpointACLArgs = PrivateEndpointACLArgs(
        allow = allow,
        deny = deny,
        name = name ?: throw PulumiNullFieldException("name"),
    )
}
